@@ -12,10 +12,8 @@
 
 namespace xmlpp
 {
-
-  /**
-   * This class set KeepBlanksDefault and IndentTreeOutput of libxmlpp
-   * and restore their initial value in its destructor. As a consequence
+  /** This class sets KeepBlanksDefault and IndentTreeOutput of libxmlpp
+   * and restores their initial values in its destructor. As a consequence
    * the wanted setting is kept during instance lifetime.
    */
   class LIBXMLPP_API KeepBlanks {
@@ -23,14 +21,13 @@ namespace xmlpp
       static const bool Default = true;
 
     public:
-      KeepBlanks(bool value);
-      ~KeepBlanks();
+      KeepBlanks(bool value) noexcept;
+      ~KeepBlanks() noexcept;
 
     private:
       int oldKeepBlanksDefault_;
       int oldIndentTreeOutput_;
   };
-
 }
 
 #endif // __LIBXMLPP_KEEPBLANKS_H
