@@ -18,9 +18,10 @@
 namespace xmlpp
 {
 
-/** Element nodes have attributes as well as child nodes. This will be instantiated by the parser.
+/** %Element nodes have attributes as well as child nodes.
+ * This will be instantiated by the parser.
  */
-class Element : public Node
+class LIBXMLPP_API Element : public Node
 {
 public:
   explicit Element(_xmlNode* node);
